@@ -3,8 +3,6 @@
 
 #include "languagemodel.h"
 
-#include <QDebug>
-
 using namespace Qt::Literals::StringLiterals;
 
 RawLanguageModel::RawLanguageModel(QObject *parent)
@@ -74,3 +72,5 @@ QModelIndex RawLanguageModel::indexOfValue(const QString &code)
         return {};
     }
 }
+
+#include "moc_languagemodel.cpp"
