@@ -9,7 +9,7 @@
 #include <QDebug>
 #include <QUrl>
 
-#include "../network/networkcontroller.h"
+#include "networkcontroller.h"
 
 AndroidUtils::AndroidUtils(QObject *parent)
     : QObject(parent)
@@ -24,7 +24,7 @@ AndroidUtils &AndroidUtils::instance()
 
 void AndroidUtils::checkPendingIntents()
 {
-    QJniObject activity = QJniObject::callStaticObjectMethod("org/qtproject/qt5/android/QtNative", "activity", "()Landroid/app/Activity;");
+    QJniObject activity = QJniObject::callStaticObjectMethod("org/qtproject/qt/android/QtNative", "activity", "()Landroid/app/Activity;");
     Q_ASSERT(activity.isValid());
 
     QJniObject::callStaticMethod<void>("org/kde/tokodon/OpenUriActivity", "checkPendingIntents");
@@ -39,4 +39,6 @@ JNIEXPORT void JNICALL Java_org_kde_tokodon_AndroidUtils_openUri(JNIEnv *env, jo
     NetworkController::instance().setAuthCode(QUrl(QString::fromUtf8(pathStr)));
     env->ReleaseStringUTFChars(path, pathStr);
 }
-}
\ No newline at end of file
+}
+
+#include "moc_androidutils.cpp"
\ No newline at end of file
