@@ -3,8 +3,7 @@
 
 #pragma once
 
-#include <QObject>
-#include <QtQml/qqmlregistration.h>
+#include <QQuickTextDocument>
 
 class AbstractAccount;
 
@@ -21,4 +20,6 @@ public:
     Q_INVOKABLE void downloadFile(AbstractAccount *account, const QString &url, const QString &destination) const;
     Q_INVOKABLE QString url(const QUrl &url) const;
     Q_INVOKABLE QString fileName(const QUrl &url) const;
+
+    Q_INVOKABLE void forceRefreshTextDocument(QQuickTextDocument *textDocument, QQuickItem *item);
 };
